* \-\-\- Benvenuto su Spotted DMI\! \-\-\- *

1\. _Di cosa si tratta?_

Questo bot permette agli studenti di tutto l'ateneo di pubblicare un messaggio una foto o un video nel canale {channel_tag}, restando totalmente anonimi\.

2\. _Come si usa?_

Il comando /help mostra una serie di comandi con cui è possibile interagire col bot\. È consigliabile anche consultare il menu /rules per evitare fraintendimenti\. 

3\. _Da cosa è garantito l'anonimato? Perché dovrei fidarmi?_

Di default, il post viene pubblicato anonimamente: in questo modo, non ci sarà alcun riferimento all'autore\.
Puoi cambiare questa preferenza in qualsiasi momento con il comando /settings, a patto di avere un username associato al tuo account telegram\.

Il codice sorgente del bot \(per gli ingegneri: i file che una volta avviati fanno funzionare il tutto\) è disponibile qui: [GitHub](https://github.com/UNICT-DMI/Telegram-SpottedDMI-Bot)\.
Questo garantisce che chiunque ha la possibilità di controllare come funziona il sistema o anche di creare un nuovo bot basato su questo\.

Qualsiasi messaggio viene ricevuto da noi senza nessun riferimento al mittente\.
Per maggiori informazioni, consulta la nostra [Privacy Policy](https://unict-dmi.github.io/Telegram-SpottedDMI-Bot/privacy)\.
